<?php

namespace Drupal\Tests\gifplayer\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests the GifPlayer module.
 *
 * @group many_selects
 */
class GifPlayerAdminTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['node', 'gifplayer'];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    // Make sure to complete the normal setup steps first.
    parent::setUp();

    // Create and log in an administrative user.
    $this->drupalLogin($this->rootUser);
  }

  /**
   * Tests if user can load the front page among other things.
   */
  public function testLoadSite() {
    // Load the front page.
    $this->drupalGet('<front>');

    // Confirm that the site didn't throw a server error or something else.
    $this->assertSession()->statusCodeEquals(200);
    $this->drupalGet("user");
  }

  /**
   * Tests if an admin user can log in.
   */
  public function testAdminUser() {
    // Log in an administrative user.
    $this->drupalLogin($this->rootUser);

    $this->drupalGet('admin/config');

    $session = $this->assertSession();
    $session->statusCodeEquals(200);
  }

  /**
   * Tests if an admin user can go to the GifPlayer's admin page.
   */
  public function testGifPlayerAdminUser() {
    // Log in an administrative user.
    $this->drupalLogin($this->rootUser);

    $this->drupalGet('admin/config/content/gifplayer');

    $session = $this->assertSession();
    $session->statusCodeEquals(200);

    $session->pageTextContains('Attach GifPlayer library globally.');
    $session->pageTextContains('Check it to load GifPlayer library globally.');
    $session->pageTextContains('File will be used as cover for the GIF player fields.');
    $session->buttonExists("Save configuration");

    $edit = [
      'library_attach' => '1',
    ];

    // It's ok, we are not testing the cover file.
    $this->submitForm($edit, 'Save configuration');
    $session->pageTextContains('Png cover cannot be empty');
  }

  /**
   * Tests if user can load the front page after the changes.
   */
  public function testLoadSiteAfterChanges() {
    // Load the front page.
    $this->drupalGet('<front>');

    // Confirm that the site didn't throw a server error or something else.
    $this->assertSession()->statusCodeEquals(200);
    $this->drupalGet("user");
  }

  /**
   * Tests if an admin access to pages again.
   */
  public function testAdminUserAfterChanges() {
    // Log in an administrative user.
    $this->drupalLogin($this->rootUser);

    $this->drupalGet('admin/modules');

    $session = $this->assertSession();
    $session->statusCodeEquals(200);
  }

}
